==> kubernetes-model-gatewayapi-6.6.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPHeaderFilterFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPHeaderFilterFluent<A extends HTTPHeaderFilterFluent<A>> extends Fluent<A>{
  public A addToAdd(Integer index,HTTPHeader item);
  public A setToAdd(Integer index,HTTPHeader item);
  public A addToAdd(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPHeader... items);
  public A addAllToAdd(Collection<HTTPHeader> items);
  public A removeFromAdd(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPHeader... items);
  public A removeAllFromAdd(Collection<HTTPHeader> items);
  public A removeMatchingFromAdd(Predicate<HTTPHeaderBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAdd instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPHeader> getAdd();
  public List<HTTPHeader> buildAdd();
  public HTTPHeader buildAdd(Integer index);
  public HTTPHeader buildFirstAdd();
  public HTTPHeader buildLastAdd();
  public HTTPHeader buildMatchingAdd(Predicate<HTTPHeaderBuilder> predicate);
  public Boolean hasMatchingAdd(Predicate<HTTPHeaderBuilder> predicate);
  public A withAdd(List<HTTPHeader> add);
  public A withAdd(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPHeader... add);
  public Boolean hasAdd();
  public A addNewAdd(String name,String value);
  public HTTPHeaderFilterFluent.AddNested<A> addNewAdd();
  public HTTPHeaderFilterFluent.AddNested<A> addNewAddLike(HTTPHeader item);
  public HTTPHeaderFilterFluent.AddNested<A> setNewAddLike(Integer index,HTTPHeader item);
  public HTTPHeaderFilterFluent.AddNested<A> editAdd(Integer index);
  public HTTPHeaderFilterFluent.AddNested<A> editFirstAdd();
  public HTTPHeaderFilterFluent.AddNested<A> editLastAdd();
  public HTTPHeaderFilterFluent.AddNested<A> editMatchingAdd(Predicate<HTTPHeaderBuilder> predicate);
  public A addToRemove(Integer index,String item);
  public A setToRemove(Integer index,String item);
  public A addToRemove(java.lang.String... items);
  public A addAllToRemove(Collection<String> items);
  public A removeFromRemove(java.lang.String... items);
  public A removeAllFromRemove(Collection<String> items);
  public List<String> getRemove();
  public String getRemove(Integer index);
  public String getFirstRemove();
  public String getLastRemove();
  public String getMatchingRemove(Predicate<String> predicate);
  public Boolean hasMatchingRemove(Predicate<String> predicate);
  public A withRemove(List<String> remove);
  public A withRemove(java.lang.String... remove);
  public Boolean hasRemove();
  public A addToSet(Integer index,HTTPHeader item);
  public A setToSet(Integer index,HTTPHeader item);
  public A addToSet(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPHeader... items);
  public A addAllToSet(Collection<HTTPHeader> items);
  public A removeFromSet(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPHeader... items);
  public A removeAllFromSet(Collection<HTTPHeader> items);
  public A removeMatchingFromSet(Predicate<HTTPHeaderBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSet instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPHeader> getSet();
  public List<HTTPHeader> buildSet();
  public HTTPHeader buildSet(Integer index);
  public HTTPHeader buildFirstSet();
  public HTTPHeader buildLastSet();
  public HTTPHeader buildMatchingSet(Predicate<HTTPHeaderBuilder> predicate);
  public Boolean hasMatchingSet(Predicate<HTTPHeaderBuilder> predicate);
  public A withSet(List<HTTPHeader> set);
  public A withSet(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPHeader... set);
  public Boolean hasSet();
  public A addNewSet(String name,String value);
  public HTTPHeaderFilterFluent.SetNested<A> addNewSet();
  public HTTPHeaderFilterFluent.SetNested<A> addNewSetLike(HTTPHeader item);
  public HTTPHeaderFilterFluent.SetNested<A> setNewSetLike(Integer index,HTTPHeader item);
  public HTTPHeaderFilterFluent.SetNested<A> editSet(Integer index);
  public HTTPHeaderFilterFluent.SetNested<A> editFirstSet();
  public HTTPHeaderFilterFluent.SetNested<A> editLastSet();
  public HTTPHeaderFilterFluent.SetNested<A> editMatchingSet(Predicate<HTTPHeaderBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface AddNested<N> extends Nested<N>,HTTPHeaderFluent<HTTPHeaderFilterFluent.AddNested<N>>{
    public N and();
    public N endAdd();
    
  }
  public interface SetNested<N> extends Nested<N>,HTTPHeaderFluent<HTTPHeaderFilterFluent.SetNested<N>>{
    public N and();
    public N endSet();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPHeaderFilterFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPHeaderFilterFluent<A extends HTTPHeaderFilterFluent<A>> extends Fluent<A>{
  public A addToAdd(int index,HTTPHeader item);
  public A setToAdd(int index,HTTPHeader item);
  public A addToAdd(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPHeader... items);
  public A addAllToAdd(Collection<HTTPHeader> items);
  public A removeFromAdd(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPHeader... items);
  public A removeAllFromAdd(Collection<HTTPHeader> items);
  public A removeMatchingFromAdd(Predicate<HTTPHeaderBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAdd instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPHeader> getAdd();
  public List<HTTPHeader> buildAdd();
  public HTTPHeader buildAdd(int index);
  public HTTPHeader buildFirstAdd();
  public HTTPHeader buildLastAdd();
  public HTTPHeader buildMatchingAdd(Predicate<HTTPHeaderBuilder> predicate);
  public Boolean hasMatchingAdd(Predicate<HTTPHeaderBuilder> predicate);
  public A withAdd(List<HTTPHeader> add);
  public A withAdd(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPHeader... add);
  public Boolean hasAdd();
  public A addNewAdd(String name,String value);
  public HTTPHeaderFilterFluent.AddNested<A> addNewAdd();
  public HTTPHeaderFilterFluent.AddNested<A> addNewAddLike(HTTPHeader item);
  public HTTPHeaderFilterFluent.AddNested<A> setNewAddLike(int index,HTTPHeader item);
  public HTTPHeaderFilterFluent.AddNested<A> editAdd(int index);
  public HTTPHeaderFilterFluent.AddNested<A> editFirstAdd();
  public HTTPHeaderFilterFluent.AddNested<A> editLastAdd();
  public HTTPHeaderFilterFluent.AddNested<A> editMatchingAdd(Predicate<HTTPHeaderBuilder> predicate);
  public A addToRemove(int index,String item);
  public A setToRemove(int index,String item);
  public A addToRemove(java.lang.String... items);
  public A addAllToRemove(Collection<String> items);
  public A removeFromRemove(java.lang.String... items);
  public A removeAllFromRemove(Collection<String> items);
  public List<String> getRemove();
  public String getRemove(int index);
  public String getFirstRemove();
  public String getLastRemove();
  public String getMatchingRemove(Predicate<String> predicate);
  public Boolean hasMatchingRemove(Predicate<String> predicate);
  public A withRemove(List<String> remove);
  public A withRemove(java.lang.String... remove);
  public Boolean hasRemove();
  public A addToSet(int index,HTTPHeader item);
  public A setToSet(int index,HTTPHeader item);
  public A addToSet(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPHeader... items);
  public A addAllToSet(Collection<HTTPHeader> items);
  public A removeFromSet(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPHeader... items);
  public A removeAllFromSet(Collection<HTTPHeader> items);
  public A removeMatchingFromSet(Predicate<HTTPHeaderBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSet instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPHeader> getSet();
  public List<HTTPHeader> buildSet();
  public HTTPHeader buildSet(int index);
  public HTTPHeader buildFirstSet();
  public HTTPHeader buildLastSet();
  public HTTPHeader buildMatchingSet(Predicate<HTTPHeaderBuilder> predicate);
  public Boolean hasMatchingSet(Predicate<HTTPHeaderBuilder> predicate);
  public A withSet(List<HTTPHeader> set);
  public A withSet(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPHeader... set);
  public Boolean hasSet();
  public A addNewSet(String name,String value);
  public HTTPHeaderFilterFluent.SetNested<A> addNewSet();
  public HTTPHeaderFilterFluent.SetNested<A> addNewSetLike(HTTPHeader item);
  public HTTPHeaderFilterFluent.SetNested<A> setNewSetLike(int index,HTTPHeader item);
  public HTTPHeaderFilterFluent.SetNested<A> editSet(int index);
  public HTTPHeaderFilterFluent.SetNested<A> editFirstSet();
  public HTTPHeaderFilterFluent.SetNested<A> editLastSet();
  public HTTPHeaderFilterFluent.SetNested<A> editMatchingSet(Predicate<HTTPHeaderBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface AddNested<N> extends Nested<N>,HTTPHeaderFluent<HTTPHeaderFilterFluent.AddNested<N>>{
    public N and();
    public N endAdd();
    
  }
  public interface SetNested<N> extends Nested<N>,HTTPHeaderFluent<HTTPHeaderFilterFluent.SetNested<N>>{
    public N and();
    public N endSet();
    
  }
  
}
